%% analytical solution for MRB rigid spring

clear all
clc


L = 30; % m
E = 2.943e10; % Pa
niu = 0.2; % Poission's Ratio
I = 8.65; % m^4

m = 36e3; % kg/m
d = 17.5;


Mv = 270e3; % kg
kv = 41350e3; % N/m
v = 27.78; % m/s
g = 9.8; % m/s^2



P = -Mv * g;
w = sqrt(E * I/m) * pi^2/L^2;
T = 2 * P * L/(m * (-w^2 * L^2 + pi^2 * v^2));

x = L/2;
t = 0:0.001:((L)/v);
y = T * (pi * v * sin(w * t)/ (w * L) - sin(pi * v * t/L)) * sin(pi * x/L); % vertical displacement during the period after the first wheel acting on the beam while the second wheel is not
y = y';

xa = 0:0.5:L;
% t = 0:0.001:((L)/v);
tf = L/v;
ya = T * (pi * v * sin(w * tf)/ (w * L) - sin(pi * v * tf/L)) * sin(pi * xa/L); % the vertical displacement at the time point when the second wheel is about to act on the beam (only considers the first wheel load)
va = T * (pi * v * w * cos(w * tf)/ (w * L) - pi * v/L * cos(pi * v * tf/L)) * sin(pi * xa/L);
% y = y';

time = t;
ymid = y;
figure();
plot(y)
% y1 = diff(y)';
% figure();
% plot(y1)

% post time 
tp = 0:0.001:(d/v);
x = L/2;
f0 = ya; % 1.08s as this IC
f1 = va;
% A = (2/(L * w)) * int(f1 * sin(pi * xx/L),xx,0,L);
% B = (2/L) * int(f0 * sin(pi * xx/L),xx,0,L);
f0s = f0 .* sin(pi * xa/L); % use the response at time point when the second wheel is about to act on the beam as an 'initialc condition' of the second time period, which only considers the second wheel load
f1s = f1 .* sin(pi * xa/L);
A = (2/(L * w)) * trapz(xa,f1s);
B = (2/L) * trapz(xa,f0s);
yp = (A * sin(w * tp) + B * cos(w * tp)) * sin(pi * x/L);
yp = yp';
vp = w * (A * cos(w * tp) - B * sin(w * tp)) * sin(pi * x/L);

% Here I use the supoposition principle in the excel to generate the total response of the beam by supoposing the two time histories considering two wheels acting periods

data = xlsread('SM0420rigid.xlsx'); % both ABAQUS and MATLAB results are saved here
timeVBI = data(1:451,3);
ymidVBI = data(1:451,4);
% figure();
% plot(y)
% y1 = diff(y)';
% figure();
% plot(y1)

dtVBI = timeVBI(length(timeVBI))/length(timeVBI);
% y' = dy/dx
y1VBI = diff(ymidVBI)/dtVBI;
y1VBI = y1VBI';
y1VBI = detrend(y1VBI);

figure()   % displacement

plot(data(:,1), data(:,2),'b')
hold on
plot(timeVBI, ymidVBI,'r--')
% legend('analytical','VBI')
grid on;
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [16.5 11]);
xlabel('Time(s)','FontSize',20,'FontWeight','bold');
ylabel('Amplitude of displacement(m)','FontSize',20,'FontWeight','bold');
legend({'response of ABAQUS applying VBI','Analytical through MATLAB'},'Location','best','FontSize',20);
set(gca,'FontSize',30)
box on


figure()  % velocity  
% plot(x(1:end-1), y(1:end-1), x(1:end-1), y1)
plot(time(1:end-1), y1,'b')
hold on
plot(timeVBI(1:end-1), y1VBI,'r--')
% legend('analytical','VBI')
grid on;
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [16.5 11]);
xlabel('Time(s)','FontSize',20,'FontWeight','bold');
ylabel('Amplitude of velocity(m/s)','FontSize',20,'FontWeight','bold');
legend({'response of ABAQUS applying VBI','Analytical through MATLAB'},'Location','best','FontSize',20);
set(gca,'FontSize',30)
box on