%% analytical solution for Sprung Mass (rigid spring)

clear all
clc



L = 25; % m
E = 2.87e9; % Pa
niu = 0.2; % Poission's Ratio
I = 2.90; % m^4

m = 2.303e3; % kg/m

Mv = 5.75e3; % kg
kv = 1595e3; % N/m
v = 27.78; % m/s
g = 9.8; % m/s^2



P = -Mv * g;
w = sqrt(E * I/m) * pi^2/L^2;
T = 2 * P * L/(m * (-w^2 * L^2 + pi^2 * v^2));

x = L/2;
t = 0:0.001:(L/v);
y = T * (pi * v * sin(w * t)/ (w * L) - sin(pi * v * t/L)) * sin(pi * x/L);
y = y';

time = t;
ymid = y;


dt = time(length(t))/length(t);
% y' = dy/dx
y1 = diff(ymid)/dt;
y1 = y1';

data = xlsread('SM0420rigid.xlsx'); % both the ABAQUS and MATLAB results are saved here
timeVBI = data(1:451,3);
ymidVBI = data(1:451,4);


dtVBI = timeVBI(length(timeVBI))/length(timeVBI);
% y' = dy/dx
y1VBI = diff(ymidVBI)/dtVBI;
y1VBI = y1VBI';


figure()   % displacement

plot(data(:,1), data(:,2),'b')
hold on
plot(timeVBI, ymidVBI,'r--')
% legend('analytical','VBI')
grid on;
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [16.5 11]);
xlabel('Time(s)','FontSize',20,'FontWeight','bold');
ylabel('Amplitude of displacement(m)','FontSize',20,'FontWeight','bold');
legend({'Analytical through MATLAB','response of ABAQUS applying VBI'},'Location','best','FontSize',20);
set(gca,'FontSize',30)
box on


figure()  % velocity  

plot(time(1:end-1), y1,'b')
hold on
plot(timeVBI(1:end-1), y1VBI,'r--')
% legend('analytical','VBI')
grid on;
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperSize', [16.5 11]);
xlabel('Time(s)','FontSize',20,'FontWeight','bold');
ylabel('Amplitude of velocity(m/s)','FontSize',20,'FontWeight','bold');
legend({'Analytical through MATLAB','response of ABAQUS applying VBI'},'Location','best','FontSize',20);
set(gca,'FontSize',30)
box on